@@ -255,12 +255,15 @@ impl ImportLibraryGenerator {
                 Some((3, 9)) => ("python39.def", include_str!("python39.def")),
                 Some((3, 10)) => ("python310.def", include_str!("python310.def")),
                 Some((3, 11)) => ("python311.def", include_str!("python311.def")),
+                Some((3, 12)) => ("python312.def", include_str!("python312.def")),
+                Some((3, 13)) => ("python313.def", include_str!("python313.def")),
                 _ => return Err(Error::new(ErrorKind::Other, "Unsupported Python version")),
             },
             PythonImplementation::PyPy => match self.version {
                 Some((3, 7)) => ("libpypy3-c.def", include_str!("libpypy3-c.def")),
                 Some((3, 8)) => ("libpypy3-c.def", include_str!("libpypy3-c.def")),
                 Some((3, 9)) => ("libpypy3.9-c.def", include_str!("libpypy3.9-c.def")),
+                Some((3, 10)) => ("libpypy3.10-c.def", include_str!("libpypy3.10-c.def")),
                 _ => return Err(Error::new(ErrorKind::Other, "Unsupported PyPy version")),
             },
         };
@@ -446,7 +449,7 @@ impl DllToolCommand {
 /// and falls back to the default MinGW-w64 arch prefixes.
 fn get_mingw_dlltool(arch: &str) -> Result<Command> {
     if let Ok(user_dlltool) = env::var("PYO3_MINGW_DLLTOOL") {
-        Ok(Command::new(&user_dlltool))
+        Ok(Command::new(user_dlltool))
     } else {
         let prefix_dlltool = match arch {
             // 64-bit MinGW-w64 (aka `x86_64-pc-windows-gnu`)
@@ -522,7 +525,7 @@ mod tests {
             .generate(&dir)
             .unwrap();
 
-        for minor in 7..=11 {
+        for minor in 7..=13 {
             ImportLibraryGenerator::new("x86_64", "gnu")
                 .version(Some((3, minor)))
                 .generate(&dir)
@@ -530,7 +533,7 @@ mod tests {
         }
 
         // PyPy
-        for minor in 7..=9 {
+        for minor in 7..=10 {
             ImportLibraryGenerator::new("x86_64", "gnu")
                 .version(Some((3, minor)))
                 .implementation(PythonImplementation::PyPy)
@@ -561,7 +564,7 @@ mod tests {
             .generate(&dir)
             .unwrap();
 
-        for minor in 7..=11 {
+        for minor in 7..=13 {
             ImportLibraryGenerator::new("x86_64", "msvc")
                 .version(Some((3, minor)))
                 .generate(&dir)
@@ -569,7 +572,7 @@ mod tests {
         }
 
         // PyPy
-        for minor in 7..=9 {
+        for minor in 7..=10 {
             ImportLibraryGenerator::new("x86_64", "msvc")
                 .version(Some((3, minor)))
                 .implementation(PythonImplementation::PyPy)
